(function($) {

	$.ZTFY.I18n = {

		WARNING: "!! ATTENTION !!",

		ERROR_OCCURED: "Une erreur s'est produite !",
		ERRORS_OCCURED: "Des erreurs se sont produites !",

		BAD_LOGIN_TITLE: "Erreur de connexion !",
		BAD_LOGIN_MESSAGE: "Vos paramètres d'authentification n'ont pas permis d'ouvrir de session ; veuillez vérifier ces paramètres ou contacter l'administrateur du site.",

		CONFIRM: "Confirmation",
		CONFIRM_REMOVE: "La suppression de ce contenu ne pourra pas être annulée. Confirmez-vous ?",

		NO_UPDATE: "Aucune modification n'a été appliquée.",
		DATA_UPDATED: "Modifications enregistrées.",

		MISSING_OVERLAY: "Le plug-in JQuery « overlay » est nécessaire ; veuillez inclure les ressources JQuery-tools dans votre page !"

	}

})(jQuery);